%define anolis_release 2

# API/ABI check
%global apiver      20230831
%global zendver     20230831
%global pdover      20170320
%global zipver      1.21.1
%bcond_with   zts
%bcond_with   firebird
%bcond_with   freetds
%bcond_without   sodium
%bcond_with   pspell
%bcond_with   tidy
%bcond_with   db4
%bcond_with   qdbm
%bcond_with      modphp
%bcond_with      imap
%bcond_without   lmdb

# we don't want -z defs linker flag
%undefine _strict_symbol_defs_build

# Adds -z now to the linker flags
%global _hardened_build 1

# version used for php embedded library soname
%global embed_version 8.3

%global mysql_sock %(mysql_config --socket 2>/dev/null || echo /var/lib/mysql/mysql.sock)

# Regression tests take a long time, you can skip 'em with this
#global runselftest 0
%{!?runselftest: %global runselftest 1}

# Use the arch-specific mysql_config binary to avoid mismatch with the
# arch detection heuristic used by bindir/mysql_config.
%global mysql_config %{_libdir}/mysql/mysql_config

# needed at srpm build time, when httpd-devel not yet installed
%{!?_httpd_mmn:        %{expand: %%global _httpd_mmn        %%(cat %{_includedir}/httpd/.mmn 2>/dev/null || echo 0-0)}}

Summary: PHP scripting language for creating dynamic web sites
Name: php
Version: 8.3.19
Release: %{anolis_release}%{?dist}
# All files licensed under PHP version 3.01, except
# Zend is licensed under Zend
# TSRM is licensed under BSD
# main/snprintf.c, main/spprintf.c and main/rfc1867.c are ASL 1.0
# ext/date/lib is MIT
# Zend/zend_sort is NCSA
# Zend/asm is Boost
License: PHP-3.01 AND Zend-2.0 AND BSD-2-Clause AND MIT AND Apache-1.0 AND NCSA AND BSL-1.0
URL: http://www.php.net/

Source0: https://www.php.net/distributions/php-%{version}.tar.xz
Source1: php.conf
Source2: php.ini
Source3: macros.php
Source4: php-fpm.conf
Source5: php-fpm-www.conf
Source6: php-fpm.service
Source7: php-fpm.logrotate
Source9: php.modconf
Source12: php-fpm.wants
Source13: nginx-fpm.conf
Source14: nginx-php.conf
# See https://secure.php.net/gpg-keys.php
Source20: https://www.php.net/distributions/php-keyring.gpg
# Configuration files for some extensions
Source50: 10-opcache.ini
Source51: opcache-default.blacklist
Source53: 20-ffi.ini

# Build fixes
Patch1: php-7.4.0-httpd.patch
Patch5: php-7.2.0-includedir.patch
Patch6: php-8.0.0-embed.patch
Patch8: php-8.1.0-libdb.patch

Patch41: php-8.3.3-parser.patch
Patch42: php-8.3.11-systzdata-v24.patch
Patch43: php-7.4.0-phpize.patch
Patch45: php-7.4.0-ldap_r.patch
Patch47: php-8.3.13-phpinfo.patch
Patch48: php-8.3.0-openssl-ec-param.patch
Patch49: php-8.3.7-argon2.patch
# Upstream fixes (100+)

# Security fixes (200+)

# Fixes for tests (300+)
# Factory is droped from system tzdata
Patch300: php-7.4.0-datetests.patch
#From https://github.com/php/php-src/commit/9cb3d8d200f0c822b17bda35a2a67a97b039d3e1
Patch301: 1000-fix-CVE-2025-6491.patch
#From https://github.com/php/php-src/commit/9376aeef9f8ff81f2705b8016237ec3e30bdee44
Patch302: 1000-fix-CVE-2025-1735.patch


BuildRequires: gnupg2
BuildRequires: bzip2-devel
BuildRequires: pkgconfig(libcurl)  >= 7.29.0
BuildRequires: httpd-devel >= 2.0.46-1
BuildRequires: pam-devel
# to ensure we are using httpd with filesystem feature 
BuildRequires: httpd-filesystem
# to ensure we are using nginx with filesystem feature 
BuildRequires: nginx-filesystem
BuildRequires: libstdc++-devel
# no pkgconfig to avoid compat-openssl10
BuildRequires: systemtap-sdt-dtrace
BuildRequires: systemtap-sdt-devel
BuildRequires: libtool-ltdl-devel
BuildRequires: libtool
BuildRequires: gcc-c++
BuildRequires: gcc
BuildRequires: make
BuildRequires: automake
BuildRequires: autoconf
BuildRequires: perl-interpreter
BuildRequires: bzip2
BuildRequires: pkgconfig(libxcrypt)
BuildRequires: pkgconfig(libpcre2-8) >= 10.30
BuildRequires: pkgconfig(libedit)
BuildRequires: smtpdaemon
BuildRequires: pkgconfig(zlib) >= 1.2.0.4
BuildRequires: pkgconfig(sqlite3) >= 3.7.4
BuildRequires: openssl-devel >= 1.0.2
# used for tests
BuildRequires: %{_bindir}/ps
BuildRequires: tzdata

%if %{with zts}
Provides: php-zts = %{version}-%{release}
%endif

%if %{with modphp}
Requires: httpd-mmn = %{_httpd_mmn}
Provides: mod_php                = %{version}-%{release}
# To ensure correct /var/lib/php/session ownership:
Requires(pre): httpd-filesystem
# php engine for Apache httpd webserver
Provides: php(httpd)
# mod_php is deprecated, no package should requires php or mod_php
# all packages must requires used SAPI (cli, fpm, embded..)
# and used extrensions (mysqli, mbstring, xmlwriter...)
Provides: deprecated()
%else
# preserve old behavior
Recommends: httpd
%endif
Requires: php-common     = %{version}-%{release}
# For backwards-compatibility, pull the "php" command
Recommends: php-cli      = %{version}-%{release}
# httpd have threaded MPM by default
Recommends: php-fpm      = %{version}-%{release}
# as "php" is now mostly a meta-package, commonly used extensions
# reduce diff with "dnf module install php"
Recommends: php-mbstring = %{version}-%{release}
Recommends: php-opcache  = %{version}-%{release}
Recommends: php-pdo      = %{version}-%{release}
%if %{with sodium}
Recommends: php-sodium   = %{version}-%{release}
%endif
Recommends: php-xml      = %{version}-%{release}


%description
PHP is an HTML-embedded scripting language. PHP attempts to make it
easy for developers to write dynamically generated web pages. PHP also
offers built-in database integration for several commercial and
non-commercial database management systems, so writing a
database-enabled webpage with PHP is fairly simple. The most common
use of PHP coding is probably as a replacement for CGI scripts.
%if %{with modphp}
The php package contains the module (often referred to as mod_php)
which adds support for the PHP language to Apache HTTP Server when
running in prefork mode. This module is deprecated.
%endif

%package cli
Summary: Command-line interface for PHP
# sapi/cli/ps_title.c is PostgreSQL
License: PHP-3.01 AND Zend-2.0 AND BSD-2-Clause AND MIT AND Apache-1.0 AND NCSA AND PostgreSQL
Requires: php-common = %{version}-%{release}
Provides: php-cgi = %{version}-%{release}
Provides: php-pcntl
Provides: php-readline

%description cli
The php-cli package contains the command-line interface
executing PHP scripts, /usr/bin/php, and the CGI interface.


%package dbg
Summary: The interactive PHP debugger
Requires: php-common = %{version}-%{release}

%description dbg
The php-dbg package contains the interactive PHP debugger.


%package fpm
Summary: PHP FastCGI Process Manager
BuildRequires: libacl-devel
BuildRequires: pkgconfig(libsystemd) >= 209
BuildRequires: pkgconfig(libselinux)
Requires: php-common = %{version}-%{release}
%{?systemd_requires}
# To ensure correct /var/lib/php/session ownership:
Requires(pre): httpd-filesystem
# For php.conf in /etc/httpd/conf.d
# and version 2.4.10 for proxy support in SetHandler
Requires: httpd-filesystem >= 2.4.10
# php engine for Apache httpd webserver
Provides: php(httpd)
# for /etc/nginx ownership
Requires: nginx-filesystem

%description fpm
PHP-FPM (FastCGI Process Manager) is an alternative PHP FastCGI
implementation with some additional features useful for sites of
any size, especially busier sites.

%package common
Summary: Common files for PHP
# All files licensed under PHP version 3.01, except
# fileinfo is licensed under PHP version 3.0
# regex, libmagic are licensed under BSD
License: PHP-3.01 AND BSD-2-Clause
Requires: tzdata
# ABI/API check - Arch specific
Provides: php(api) = %{apiver}
Provides: php(zend-abi) = %{zendver}
Provides: php(language) = %{version}
# Provides for all builtin/shared modules:
Provides: php-zlib
Provides: php-tokenizer
Provides: php-standard = %{version}
Provides: php-spl
Provides: php-sockets
Provides: php-session
Provides: php-reflection
Provides: php-pcre
Provides: php-phar
Provides: php-openssl
Provides: php-libxml
Provides: php-json = %{version}
Obsoletes: php-json < 8
Obsoletes: php-pecl-zip < %{version}
Provides: php-iconv
Provides: php-mhash = %{version}
Provides: php-hash
Provides: php-gettext
Provides: php-ftp
Provides: php-filter
Provides: bundled(libmagic) = 5.29
Provides: php-fileinfo
Provides: php-exif
Provides: bundled(timelib)
Provides: php-date
Provides: php-curl
Provides: php-ctype
Provides: php-core = %{version}
Provides: php-calendar
Provides: php-bz2, php-bz2

%description common
The php-common package contains files used by both the php
package and the php-cli package.

%package devel
Summary: Files needed for building PHP extensions
Requires: php-cli = %{version}-%{release}
# always needed to build extension
Requires: autoconf
Requires: automake
Requires: make
Requires: gcc
Requires: gcc-c++
Requires: libtool
# see "php-config --libs"
Requires: krb5-devel
Requires: libxml2-devel
Requires: openssl-devel >= 1.0.2
Requires: pcre2-devel
Requires: zlib-devel
%if %{with zts}
Provides: php-zts-devel = %{version}-%{release}
%endif
Recommends: php-nikic-php-parser5 >= 5.0.0


%description devel
The php-devel package contains the files needed for building PHP
extensions. If you need to compile your own PHP extensions, you will
need to install this package.

%package ffi
Summary: Foreign Function Interface
# All files licensed under PHP version 3.0.1
License: PHP
Group: System Environment/Libraries
BuildRequires:  pkgconfig(libffi)
Requires: php-common = %{version}-%{release}

%description ffi
FFI is one of the features that made Python and LuaJIT very useful for fast
prototyping. It allows calling C functions and using C data types from pure
scripting language and therefore develop “system code” more productively.

For PHP, FFI opens a way to write PHP extensions and bindings to C libraries
in pure PHP.


%if %{with sodium}
%package sodium
Summary: Wrapper for the Sodium cryptographic library
# All files licensed under PHP version 3.0.1
License: PHP
BuildRequires:  pkgconfig(libsodium) >= 1.0.9

Requires: php-common = %{version}-%{release}
Obsoletes: php-pecl-libsodium2 < 3
Provides:  php-pecl(libsodium)         = %{version}

%description sodium
The php-sodium package provides a simple,
low-level PHP extension for the libsodium cryptographic library.
%endif

%package enchant
Summary: Enchant spelling extension for PHP applications
# All files licensed under PHP version 3.0
License: PHP
Requires: php-common = %{version}-%{release}
BuildRequires: pkgconfig(enchant-2)

%description enchant
The php-enchant package contains a dynamic shared object that will add
support for using the enchant library to PHP.

%package intl
Summary: Internationalization extension for PHP applications
# All files licensed under PHP version 3.01
License: PHP
Requires: php-common = %{version}-%{release}
BuildRequires: pkgconfig(icu-i18n) >= 50.1
BuildRequires: pkgconfig(icu-io)   >= 50.1
BuildRequires: pkgconfig(icu-uc)   >= 50.1

%description intl
The php-intl package contains a dynamic shared object that will add
support for using the ICU library to PHP.

%if %{with pspell}
%package pspell
Summary: A module for PHP applications for using pspell interfaces
# All files licensed under PHP version 3.01
License: PHP
Requires: php-common = %{version}-%{release}
BuildRequires: aspell-devel >= 0.50.0

%description pspell
The php-pspell package contains a dynamic shared object that will add
support for using the pspell library to PHP.
%endif

%package embedded
Summary: PHP library for embedding in applications
Requires: php-common = %{version}-%{release}
# doing a real -devel package for just the .so symlink is a bit overkill
Provides: php-embedded-devel = %{version}-%{release}

%description embedded
The php-embedded package contains a library which can be embedded
into applications to provide PHP scripting language support.

%if %{with freetds}
%package pdo-dblib
Summary: PDO driver for Microsoft SQL Server and Sybase databases
# All files licensed under PHP version 3.01
License: PHP
Requires: php-pdo = %{version}-%{release}
BuildRequires: freetds-devel
Provides: php-pdo_dblib

%description pdo-dblib
The php-pdo-dblib package contains a dynamic shared object
that implements the PHP Data Objects (PDO) interface to enable access from
PHP to Microsoft SQL Server and Sybase databases through the FreeTDS library.
%endif

%if %{with tidy}
%package tidy
Summary: Standard PHP module provides tidy library support
# All files licensed under PHP version 3.01
License:  PHP-3.01
Requires: php-common = %{version}-%{release}
BuildRequires: libtidy-devel

%description tidy
The php-tidy package contains a dynamic shared object that will add
support for using the tidy library to PHP.
%endif

%package dba
Summary: A database abstraction layer module for PHP applications
# All files licensed under PHP version 3.01
License: PHP
%if %{with db4}
BuildRequires: libdb-devel
%endif
BuildRequires: tokyocabinet-devel
%if %{with lmdb}
BuildRequires: lmdb-devel
%endif
%if %{with qdbm}
BuildRequires: qdbm-devel
%endif
Requires: php-common = %{version}-%{release}

%description dba
The php-dba package contains a dynamic shared object that will add
support for using the DBA database abstraction layer to PHP.

%package gmp
Summary: A module for PHP applications for using the GNU MP library
# All files licensed under PHP version 3.01
License: PHP
BuildRequires: gmp-devel
Requires: php-common = %{version}-%{release}

%description gmp
These functions allow you to work with arbitrary-length integers
using the GNU MP library.

%package bcmath
Summary: A module for PHP applications for using the bcmath library
# All files licensed under PHP version 3.01, except
# libbcmath is licensed under LGPLv2+
License: PHP and LGPLv2+
Requires: php-common = %{version}-%{release}

%description bcmath
The php-bcmath package contains a dynamic shared object that will add
support for using the bcmath library to PHP.

%package gd
Summary: A module for PHP applications for using the gd graphics library
# All files licensed under PHP version 3.01
License:  PHP-3.01
Requires: php-common = %{version}-%{release}
BuildRequires: pkgconfig(gdlib) >= 2.1.1

%description gd
The php-gd package contains a dynamic shared object that will add
support for using the gd graphics library to PHP.

%package mbstring
Summary: A module for PHP applications which need multi-byte string handling
# All files licensed under PHP version 3.01, except
# libmbfl is licensed under LGPLv2
# ucgendat is licensed under OpenLDAP
License: PHP-3.01 AND LGPL-2.1-only AND OLDAP-2.8
BuildRequires: pkgconfig(oniguruma) >= 6.8
Provides: bundled(libmbfl) = 1.3.2
Requires: php-common = %{version}-%{release}

%description mbstring
The php-mbstring package contains a dynamic shared object that will add
support for multi-byte string handling to PHP.

%package xml
Summary: A module for PHP applications which use XML
# All files licensed under PHP version 3.01
License:  PHP-3.01
Requires: php-common = %{version}-%{release}
Provides: php-dom
Provides: php-domxml
Provides: php-simplexml
Provides: php-xmlreader
Provides: php-xmlwriter
Provides: php-xsl
BuildRequires: pkgconfig(libxslt)  >= 1.1
BuildRequires: pkgconfig(libexslt)
BuildRequires: pkgconfig(libxml-2.0)  >= 2.7.6

%description xml
The php-xml package contains dynamic shared objects which add support
to PHP for manipulating XML documents using the DOM tree,
and performing XSL transformations on XML documents.

%package snmp
Summary: A module for PHP applications that query SNMP-managed devices
# All files licensed under PHP version 3.01
License:  PHP-3.01
Requires: php-common = %{version}-%{release}, net-snmp
BuildRequires: net-snmp-devel

%description snmp
The php-snmp package contains a dynamic shared object that will add
support for querying SNMP devices to PHP.  PHP is an HTML-embeddable
scripting language. If you need SNMP support for PHP applications, you
will need to install this package and the php package.

%if %{with firebird}
%package pdo-firebird
Summary: PDO driver for Interbase/Firebird databases
# All files licensed under PHP version 3.01
License:  PHP-3.01
# for fb_config command
BuildRequires:  firebird-devel
Requires: php-pdo = %{version}-%{release}
Provides: php_database
Provides: php-pdo_firebird

%description pdo-firebird
The php-pdo-firebird package contains the PDO driver for
Interbase/Firebird databases.
%endif

%package soap
Summary: A module for PHP applications that use the SOAP protocol
# All files licensed under PHP version 3.01
License:  PHP-3.01
Requires: php-common = %{version}-%{release}
BuildRequires: pkgconfig(libxml-2.0)

%description soap
The php-soap package contains a dynamic shared object that will add
support to PHP for using the SOAP web services protocol.

%package odbc
Summary: A module for PHP applications that use ODBC databases
# All files licensed under PHP version 3.01, except
# pdo_odbc is licensed under PHP version 3.0
License:  PHP-3.01
Requires: php-pdo = %{version}-%{release}
Provides: php_database
Provides: php-pdo_odbc
BuildRequires: unixODBC-devel

%description odbc
The php-odbc package contains a dynamic shared object that will add
database support through ODBC to PHP. ODBC is an open specification
which provides a consistent API for developers to use for accessing
data sources (which are often, but not always, databases). PHP is an
HTML-embeddable scripting language. If you need ODBC support for PHP
applications, you will need to install this package and the php
package.

%package process
Summary: Modules for PHP script using system process interfaces
# All files licensed under PHP version 3.01
License:  PHP-3.01
Requires: php-common = %{version}-%{release}
Provides: php-posix
Provides: php-shmop
Provides: php-sysvsem
Provides: php-sysvshm
Provides: php-sysvmsg

%description process
The php-process package contains dynamic shared objects which add
support to PHP using system interfaces for inter-process
communication.

%package pgsql
Summary: A PostgreSQL database module for PHP
# All files licensed under PHP version 3.01
License:  PHP-3.01
Requires: php-pdo = %{version}-%{release}
Provides: php_database
Provides: php-pdo_pgsql
BuildRequires: krb5-devel
BuildRequires: openssl-devel >= 1.0.2
BuildRequires: libpq-devel

%description pgsql
The php-pgsql package add PostgreSQL database support to PHP.
PostgreSQL is an object-relational database management
system that supports almost all SQL constructs. PHP is an
HTML-embedded scripting language. If you need back-end support for
PostgreSQL, you should install this package in addition to the main
php package.

%package mysqlnd
Summary: A module for PHP applications that use MySQL databases
# All files licensed under PHP version 3.01
License:  PHP-3.01
Requires: php-pdo = %{version}-%{release}
Provides: php_database
Provides: php-mysqli = %{version}-%{release}
Provides: php-pdo_mysql

%description mysqlnd
The php-mysqlnd package contains a dynamic shared object that will add
MySQL database support to PHP. MySQL is an object-relational database
management system. PHP is an HTML-embeddable scripting language. If
you need MySQL support for PHP applications, you will need to install
this package and the php package.

This package use the MySQL Native Driver

%package pdo
Summary: A database access abstraction module for PHP applications
# All files licensed under PHP version 3.01
License:  PHP-3.01
Requires: php-common = %{version}-%{release}
# ABI/API check - Arch specific
Provides: php-pdo-abi  = %{pdover}
Provides: php(pdo-abi) = %{pdover}
Provides: php-sqlite3
Provides: php-pdo_sqlite

%description pdo
The php-pdo package contains a dynamic shared object that will add
a database access abstraction layer to PHP.  This module provides
a common interface for accessing MySQL, PostgreSQL or other
databases.

%package ldap
Summary: A module for PHP applications that use LDAP
# All files licensed under PHP version 3.01
License:  PHP-3.01
Requires: php-common = %{version}-%{release}
BuildRequires: pkgconfig(libsasl2)
BuildRequires: openldap-devel
BuildRequires: openssl-devel >= 1.0.2

%description ldap
The php-ldap adds Lightweight Directory Access Protocol (LDAP)
support to PHP. LDAP is a set of protocols for accessing directory
services over the Internet. PHP is an HTML-embedded scripting
language.

%if %{with imap}
%package imap
Summary: A module for PHP applications that use IMAP
# All files licensed under PHP version 3.0
License:  PHP-3.01
Requires: php-common = %{version}-%{release}
BuildRequires: pkgconfig(krb5)
BuildRequires: pkgconfig(krb5-gssapi)
BuildRequires: openssl-devel >= 1.0.2
BuildRequires: libc-client-devel

%description imap
The php-imap module will add IMAP (Internet Message Access Protocol)
support to PHP. IMAP is a protocol for retrieving and uploading e-mail
messages on mail servers. PHP is an HTML-embedded scripting language.
%endif


%package opcache
Summary:   The Zend OPcache
License:   PHP-3.01
BuildRequires: pkgconfig(capstone) >= 3.0
Requires:  php-common = %{version}-%{release}
Provides:  php-pecl-zendopcache = %{version}
Provides:  php-pecl(opcache) = %{version}

%description opcache
The Zend OPcache provides faster PHP execution through opcode caching and
optimization. It improves PHP performance by storing precompiled script
bytecode in the shared memory. This eliminates the stages of reading code from
the disk and compiling it on future access. In addition, it applies a few
bytecode optimization patterns that make code execution faster.

%prep
%setup -q -n php-%{version}

%patch -P 1 -p1 -b .mpmcheck
%patch -P 5 -p1 -b .includedir
%patch -P 6 -p1 -b .embed
%patch -P 8 -p1 -b .libdb

%patch -P 41 -p1 -b .syslib
%patch -P 42 -p1 -b .systzdata
%patch -P 43 -p1 -b .headers
%patch -P 45 -p1 -b .ldap_r
%patch -P 47 -p1 -b .phpinfo
%patch -P 48 -p1 -b .ec-param
%patch -P 49 -p1 -b .argon2

# upstream patches

# security patches

# Fixes for tests
%patch -P 300 -p1 -b .datetests


# Prevent %%doc confusion over LICENSE files
cp ext/date/lib/LICENSE.rst timelib_LICENSE
cp ext/bcmath/libbcmath/LICENSE libbcmath_LICENSE
cp ext/fileinfo/libmagic/LICENSE libmagic_LICENSE
cp ext/mbstring/libmbfl/LICENSE libmbfl_LICENSE
cp sapi/fpm/LICENSE fpm_LICENSE
cp Zend/asm/LICENSE BOOST_LICENSE
cp TSRM/LICENSE TSRM_LICENSE
cp Zend/LICENSE ZEND_LICENSE

# Multiple builds for multiple SAPIs
mkdir build-cgi build-embedded \
%if %{with modphp}
    build-apache \
%endif
%if %{with zts}
    build-zts build-ztscli \
%endif
    build-fpm

# ----- Manage known as failed test -------
# affected by systzdata patch
rm ext/date/tests/timezone_location_get.phpt
rm ext/date/tests/timezone_version_get.phpt
rm ext/date/tests/timezone_version_get_basic1.phpt
# fails sometime
rm ext/sockets/tests/mcast_ipv?_recv.phpt
# cause stack exhausion
rm Zend/tests/bug54268.phpt
rm Zend/tests/bug68412.phpt
# tar issue
rm ext/zlib/tests/004-mb.phpt
rm ext/openssl/tests/ecc_custom_params.phpt

# Safety check for API version change.
pver=$(sed -n '/#define PHP_VERSION /{s/.* "//;s/".*$//;p}' main/php_version.h)
if test "x${pver}" != "x%{version}"; then
   : Error: Upstream PHP version is now ${pver}, expecting %{version}.
   : Update the version macros and rebuild.
   exit 1
fi

vapi=`sed -n '/#define PHP_API_VERSION/{s/.* //;p}' main/php.h`
if test "x${vapi}" != "x%{apiver}"; then
   : Error: Upstream API version is now ${vapi}, expecting %{apiver}.
   : Update the apiver macro and rebuild.
   exit 1
fi

vzend=`sed -n '/#define ZEND_MODULE_API_NO/{s/^[^0-9]*//;p;}' Zend/zend_modules.h`
if test "x${vzend}" != "x%{zendver}"; then
   : Error: Upstream Zend ABI version is now ${vzend}, expecting %{zendver}.
   : Update the zendver macro and rebuild.
   exit 1
fi

# Safety check for PDO ABI version change
vpdo=`sed -n '/#define PDO_DRIVER_API/{s/.*[ 	]//;p}' ext/pdo/php_pdo_driver.h`
if test "x${vpdo}" != "x%{pdover}"; then
   : Error: Upstream PDO ABI version is now ${vpdo}, expecting %{pdover}.
   : Update the pdover macro and rebuild.
   exit 1
fi

# https://bugs.php.net/63362 - Not needed but installed headers.
# Drop some Windows specific headers to avoid installation,
# before build to ensure they are really not needed.
rm -f TSRM/tsrm_win32.h \
      TSRM/tsrm_config.w32.h \
      Zend/zend_config.w32.h \
      ext/mysqlnd/config-win.h \
      ext/standard/winver.h \
      main/win32_internal_function_disabled.h \
      main/win95nt.h

# Fix some bogus permissions
find . -name \*.[ch] -exec chmod 644 {} \;
chmod 644 README.*

# Some extensions have their own configuration file
cp %{SOURCE50} %{SOURCE51} %{SOURCE53} .

%build
# This package fails to build with LTO due to undefined symbols.  LTO
# was disabled in OpenSuSE as well, but with no real explanation why
# beyond the undefined symbols.  It really shold be investigated further.
# Disable LTO
%define _lto_cflags %{nil}

# Set build date from https://reproducible-builds.org/specs/source-date-epoch/
export SOURCE_DATE_EPOCH=$(date +%s -r NEWS)
export PHP_UNAME=$(uname)
export PHP_BUILD_SYSTEM=$(cat /etc/anolis-release | sed -e 's/ Beta//')
%if 0%{?vendor:1}
export PHP_BUILD_PROVIDER="%{vendor}"
%endif
export PHP_BUILD_COMPILER="$(gcc --version | head -n1)"
export PHP_BUILD_ARCH="%{_arch}"

# Force use of system libtool:
libtoolize --force --copy
cat `aclocal --print-ac-dir`/{libtool,ltoptions,ltsugar,ltversion,lt~obsolete}.m4 >build/libtool.m4

# Regenerate configure scripts (patches change config.m4's)
touch configure.ac
./buildconf --force

CFLAGS=$(echo $RPM_OPT_FLAGS -fno-strict-aliasing -Wno-pointer-sign | sed 's/-mstackrealign//')
export CFLAGS

# Install extension modules in %%{_libdir}/php/modules.
EXTENSION_DIR=%{_libdir}/php/modules; export EXTENSION_DIR

# Set PEAR_INSTALLDIR to ensure that the hard-coded include_path
# includes the PEAR directory even though pear is packaged
# separately.
PEAR_INSTALLDIR=%{_datadir}/pear; export PEAR_INSTALLDIR

# Shell function to configure and build a PHP tree.
build() {
# Old/recent bison version seems to produce a broken parser;
# upstream uses GNU Bison 2.3. Workaround:
mkdir Zend && cp ../Zend/zend_{language,ini}_{parser,scanner}.[ch] Zend

# Always static:
# date, ereg, filter, libxml, reflection, spl: not supported
# hash: for PHAR_SIG_SHA256 and PHAR_SIG_SHA512
# session: dep on hash, used by soap
# sockets: heavily used by FPM test suite
# pcre: used by filter, zip
# pcntl, readline: only used by CLI sapi
# openssl: for PHAR_SIG_OPENSSL
# zlib: used by image

ln -sf ../configure
%configure \
    --enable-dtrace \
    --without-password-argon2 \
    --with-mhash \
    --with-system-tzdata \
    --with-libxml \
    --with-kerberos \
    --with-layout=GNU \
    --with-zlib \
    --with-external-libcrypt \
    --with-external-pcre \
    --with-system-ciphers \
    --with-openssl \
    --without-gdbm \
    --without-pear \
    --disable-rpath \
    --with-pic \
    --disable-debug \
    --with-config-file-scan-dir=%{_sysconfdir}/php.d \
    --with-config-file-path=%{_sysconfdir} \
    --with-libdir=%{_lib} \
    --cache-file=../config.cache \
    --enable-rtld-now \
    --with-exec-dir=%{_bindir} \
    --enable-sockets \
    $*
if test $? != 0; then
  tail -500 config.log
  : configure failed
  exit 1
fi

%make_build
}

# Build /usr/bin/php-cgi with the CGI SAPI, and most shared extensions
pushd build-cgi

build --libdir=%{_libdir}/php \
      --enable-pcntl \
      --enable-opcache \
      --with-capstone \
      --enable-phpdbg --enable-phpdbg-readline \
%if %{with imap}
      --with-imap=shared --with-imap-ssl \
%endif
      --enable-mbstring=shared \
      --enable-mbregex \
      --enable-gd=shared \
      --with-external-gd \
      --with-gmp=shared \
      --enable-calendar=shared \
      --enable-bcmath=shared \
      --with-bz2=shared \
      --enable-ctype=shared \
      --enable-dba=shared \
%if %{with db4}
                          --with-db4=%{_prefix} \
%endif
                          --with-tcadb=%{_prefix} \
%if %{with lmdb}
                          --with-lmdb=%{_prefix} \
%endif
%if %{with qdbm}
                          --with-qdbm=%{_prefix} \
%endif
      --enable-dom=shared \
      --with-pgsql=shared \
      --enable-simplexml=shared \
      --enable-xml=shared \
      --with-snmp=shared,%{_prefix} \
      --enable-soap=shared \
      --with-xsl=shared,%{_prefix} \
      --enable-xmlreader=shared --enable-xmlwriter=shared \
      --with-curl=shared \
      --enable-pdo=shared \
      --with-pdo-odbc=shared,unixODBC,%{_prefix} \
      --with-pdo-mysql=shared,mysqlnd \
      --with-pdo-pgsql=shared,%{_prefix} \
      --with-pdo-sqlite=shared \
%if %{with firebird}
      --with-pdo-firebird=shared \
%endif
      --enable-exif=shared \
      --enable-ftp=shared \
      --with-gettext=shared \
      --with-iconv=shared \
      --enable-tokenizer=shared \
      --with-ldap=shared --with-ldap-sasl \
      --enable-mysqlnd=shared \
      --with-mysqli=shared,mysqlnd \
      --with-mysql-sock=%{mysql_sock} \
%if %{with freetds}
      --with-pdo-dblib=shared,%{_prefix} \
%endif
      --with-sqlite3=shared \
      --without-readline \
      --with-libedit \
%if %{with pspell}
      --with-pspell=shared \
%endif
      --enable-phar=shared \
%if %{with tidy}
      --with-tidy=shared,%{_prefix} \
%endif
      --enable-sysvmsg=shared --enable-sysvshm=shared --enable-sysvsem=shared \
      --enable-shmop=shared \
      --enable-posix=shared \
      --with-unixODBC=shared,%{_prefix} \
      --enable-fileinfo=shared \
      --with-ffi=shared \
%if %{with sodium}
      --with-sodium=shared \
%else
      --without-sodium \
%endif
      --enable-intl=shared \
      --with-enchant=shared
popd

without_shared="--without-gd \
      --disable-shmop -disable-tokenizer \
      --without-iconv --disable-ftp --without-bz2 --disable-ctype \
      --disable-simplexml --disable-exif --without-gettext \
      --without-curl --disable-posix --disable-xml \
      --without-pspell \
      --without-sqlite3 --disable-phar --disable-fileinfo \
      --without-sodium \
      --disable-xmlreader --disable-xmlwriter \
      --without-ffi \
      --disable-phpdbg \
      --disable-opcache \
      --disable-dom --disable-dba --without-unixODBC \
      --disable-sysvmsg --disable-sysvshm --disable-sysvsem"

%if %{with modphp}
# Build Apache module, and the CLI SAPI, /usr/bin/php
pushd build-apache
build --with-apxs2=%{_httpd_apxs} \
      --libdir=%{_libdir}/php \
      --without-mysqli \
      --disable-pdo \
      ${without_shared}
popd
%endif

# Build php-fpm
pushd build-fpm
build --enable-fpm \
      --with-fpm-acl \
      --with-fpm-systemd \
      --with-fpm-selinux \
      --libdir=%{_libdir}/php \
      --without-mysqli \
      --disable-pdo \
      ${without_shared}
popd

# Build for inclusion as embedded script language into applications,
# /usr/lib[64]/libphp.so
pushd build-embedded
build --enable-embed \
      --without-mysqli --disable-pdo \
      ${without_shared}
popd

%if %{with zts}
# Build a special thread-safe (mainly for modules)
pushd build-ztscli

EXTENSION_DIR=%{_libdir}/php-zts/modules
build --includedir=%{_includedir}/php-zts \
      --libdir=%{_libdir}/php-zts \
      --enable-zts \
      --program-prefix=zts- \
      --disable-cgi \
      --with-config-file-scan-dir=%{_sysconfdir}/php-zts.d \
      --enable-pcntl \
      --enable-opcache \
      --with-capstone \
%if %{with imap}
      --with-imap=shared --with-imap-ssl \
%endif
      --enable-mbstring=shared \
      --enable-mbregex \
      --enable-gd=shared \
      --with-external-gd \
      --with-gmp=shared \
      --enable-calendar=shared \
      --enable-bcmath=shared \
      --with-bz2=shared \
      --enable-ctype=shared \
      --enable-dba=shared \
%if %{with db4}
                          --with-db4=%{_prefix} \
%endif
                          --with-tcadb=%{_prefix} \
%if %{with lmdb}
                          --with-lmdb=%{_prefix} \
%endif
%if %{with qdbm}
                          --with-qdbm=%{_prefix} \
%endif
      --with-gettext=shared \
      --with-iconv=shared \
      --enable-tokenizer=shared \
      --enable-exif=shared \
      --enable-ftp=shared \
      --with-ldap=shared --with-ldap-sasl \
      --enable-mysqlnd=shared \
      --with-mysqli=shared,mysqlnd \
      --with-mysql-sock=%{mysql_sock} \
      --enable-mysqlnd-threading \
%if %{with firebird}
      --with-pdo-firebird=shared \
%endif
      --with-pdo-sqlite=shared \
      --with-pdo-pgsql=shared,%{_prefix} \
      --with-pdo-mysql=shared,mysqlnd \
      --with-pdo-odbc=shared,unixODBC,%{_prefix} \
      --enable-pdo=shared \
      --with-curl=shared \
      --enable-xmlreader=shared --enable-xmlwriter=shared \
      --with-xsl=shared,%{_prefix} \
      --enable-soap=shared \
      --with-snmp=shared,%{_prefix} \
      --enable-xml=shared \
      --enable-simplexml=shared \
      --with-pgsql=shared \
      --enable-dom=shared \
%if %{with freetds}
      --with-pdo-dblib=shared,%{_prefix} \
%endif
      --with-sqlite3=shared \
      --without-readline \
      --with-libedit \
%if %{with pspell}
      --with-pspell=shared \
%endif
      --enable-phar=shared \
%if %{with tidy}
      --with-tidy=shared,%{_prefix} \
%endif
      --enable-sysvmsg=shared --enable-sysvshm=shared --enable-sysvsem=shared \
      --enable-shmop=shared \
      --enable-posix=shared \
      --with-unixODBC=shared,%{_prefix} \
      --enable-fileinfo=shared \
      --with-ffi=shared \
%if %{with sodium}
      --with-sodium=shared \
%else
      --without-sodium \
%endif
      --enable-intl=shared \
      --with-enchant=shared
popd

### NOTE!!! EXTENSION_DIR was changed for the -zts build, so it must remain
### the last SAPI to be built.
%endif


%check
: Ensure proper NTS/ZTS build
$RPM_BUILD_ROOT%{_bindir}/php     -n -v | grep NTS
%if %{with zts}
$RPM_BUILD_ROOT%{_bindir}/zts-php -n -v | grep ZTS
%endif

%if %runselftest
cd build-fpm

# Run tests, using the CLI SAPI
export NO_INTERACTION=1 REPORT_EXIT_STATUS=1 MALLOC_CHECK_=2
export SKIP_ONLINE_TESTS=1
export SKIP_IO_CAPTURE_TESTS=1
unset TZ LANG LC_ALL
if ! make test TESTS=%{?_smp_mflags}; then
  set +x
  for f in $(find .. -name \*.diff -type f -print); do
    if ! grep -q XFAIL "${f/.diff/.phpt}"
    then
      echo "TEST FAILURE: $f --"
      cat "$f"
      echo -e "\n-- $f result ends."
    fi
  done
  set -x
  #exit 1
fi
unset NO_INTERACTION REPORT_EXIT_STATUS MALLOC_CHECK_
%endif

%install
%if %{with zts}
# Install the extensions for the ZTS version
make -C build-ztscli install \
     INSTALL_ROOT=$RPM_BUILD_ROOT
%endif

# Install the version for embedded script language in applications + php_embed.h
make -C build-embedded install-sapi install-headers \
     INSTALL_ROOT=$RPM_BUILD_ROOT

# Install the php-fpm binary
make -C build-fpm install-fpm \
     INSTALL_ROOT=$RPM_BUILD_ROOT

# Install everything from the CGI SAPI build
make -C build-cgi install \
     INSTALL_ROOT=$RPM_BUILD_ROOT

# Use php-config from embed SAPI to reduce used libs
install -m 755 build-embedded/scripts/php-config $RPM_BUILD_ROOT%{_bindir}/php-config

# Install the default configuration file
install -m 755 -d $RPM_BUILD_ROOT%{_sysconfdir}/
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/php.ini

# For third-party packaging:
install -m 755 -d $RPM_BUILD_ROOT%{_datadir}/php/preload

%if %{with modphp}
# install the DSO
install -m 755 -d $RPM_BUILD_ROOT%{_httpd_moddir}
install -m 755 build-apache/libs/libphp.so $RPM_BUILD_ROOT%{_httpd_moddir}
%endif

%if %{with modphp}
install -D -m 644 %{SOURCE9} $RPM_BUILD_ROOT%{_httpd_modconfdir}/20-php.conf
%endif
install -D -m 644 %{SOURCE1} $RPM_BUILD_ROOT%{_httpd_confdir}/php.conf

install -m 755 -d $RPM_BUILD_ROOT%{_sysconfdir}/php.d
%if %{with zts}
install -m 755 -d $RPM_BUILD_ROOT%{_sysconfdir}/php-zts.d
%endif
install -m 755 -d $RPM_BUILD_ROOT%{_sharedstatedir}/php
install -m 755 -d $RPM_BUILD_ROOT%{_sharedstatedir}/php/peclxml
install -m 700 -d $RPM_BUILD_ROOT%{_sharedstatedir}/php/session
install -m 700 -d $RPM_BUILD_ROOT%{_sharedstatedir}/php/wsdlcache
install -m 700 -d $RPM_BUILD_ROOT%{_sharedstatedir}/php/opcache

install -m 755 -d $RPM_BUILD_ROOT%{_docdir}/pecl
install -m 755 -d $RPM_BUILD_ROOT%{_datadir}/tests/pecl

# PHP-FPM stuff
# Log
install -m 755 -d $RPM_BUILD_ROOT%{_localstatedir}/log/php-fpm
install -m 755 -d $RPM_BUILD_ROOT/run/php-fpm
# Config
install -m 755 -d $RPM_BUILD_ROOT%{_sysconfdir}/php-fpm.d
install -m 644 %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/php-fpm.conf
install -m 644 %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/php-fpm.d/www.conf
mv $RPM_BUILD_ROOT%{_sysconfdir}/php-fpm.conf.default .
mv $RPM_BUILD_ROOT%{_sysconfdir}/php-fpm.d/www.conf.default .
# install systemd unit files and scripts for handling server startup
install -m 755 -d $RPM_BUILD_ROOT%{_sysconfdir}/systemd/system/php-fpm.service.d
install -Dm 644 %{SOURCE6}  $RPM_BUILD_ROOT%{_unitdir}/php-fpm.service
install -Dm 644 %{SOURCE12} $RPM_BUILD_ROOT%{_sysconfdir}/systemd/system/httpd.service.d/php-fpm.conf
install -Dm 644 %{SOURCE12} $RPM_BUILD_ROOT%{_sysconfdir}/systemd/system/nginx.service.d/php-fpm.conf
# LogRotate
install -m 755 -d $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d
install -m 644 %{SOURCE7} $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/php-fpm
# Nginx configuration
install -D -m 644 %{SOURCE13} $RPM_BUILD_ROOT%{_sysconfdir}/nginx/conf.d/php-fpm.conf
install -D -m 644 %{SOURCE14} $RPM_BUILD_ROOT%{_sysconfdir}/nginx/default.d/php.conf

TESTCMD="$RPM_BUILD_ROOT%{_bindir}/php --no-php-ini"
# Ensure all provided extensions are really there
for mod in core date filter hash libxml openssl pcntl pcre readline reflection session spl standard zlib
do
     $TESTCMD --modules | grep -qi $mod
done

TESTCMD="$TESTCMD --define extension_dir=$RPM_BUILD_ROOT%{_libdir}/php/modules"

# Generate files lists and stub .ini files for each subpackage
for mod in pgsql odbc ldap snmp \
%if %{with imap}
    imap \
%endif
    mysqlnd mysqli \
    mbstring gd dom xsl soap bcmath dba \
    simplexml bz2 calendar ctype exif ftp gettext gmp iconv \
    tokenizer opcache \
    sqlite3 \
    enchant phar fileinfo intl \
    ffi \
%if %{with tidy}
    tidy \
%endif
%if %{with pspell}
    pspell \
%endif
    curl \
%if %{with sodium}
    sodium \
%endif
    posix shmop sysvshm sysvsem sysvmsg xml \
    pdo pdo_mysql pdo pdo_pgsql pdo_odbc pdo_sqlite \
%if %{with firebird}
    pdo_firebird \
%endif
%if %{with freetds}
    pdo_dblib \
%endif
    xmlreader xmlwriter
do
    case $mod in
      opcache)
        # Zend extensions
        TESTCMD="$TESTCMD --define zend_extension=$mod"
        ini=10-${mod}.ini;;
      pdo_*|mysqli|xmlreader)
        # Extensions with dependencies on 20-*
        TESTCMD="$TESTCMD --define extension=$mod"
        ini=30-${mod}.ini;;
      *)
        # Extensions with no dependency
        TESTCMD="$TESTCMD --define extension=$mod"
        ini=20-${mod}.ini;;
    esac

    $TESTCMD --modules | grep -qi $mod

    # some extensions have their own config file
    if [ -f ${ini} ]; then
      cp -p ${ini} $RPM_BUILD_ROOT%{_sysconfdir}/php.d/${ini}
%if %{with zts}
      cp -p ${ini} $RPM_BUILD_ROOT%{_sysconfdir}/php-zts.d/${ini}
%endif
    else
      cat > $RPM_BUILD_ROOT%{_sysconfdir}/php.d/${ini} <<EOF
; Enable ${mod} extension module
extension=${mod}
EOF
%if %{with zts}
      cat > $RPM_BUILD_ROOT%{_sysconfdir}/php-zts.d/${ini} <<EOF
; Enable ${mod} extension module
extension=${mod}
EOF
%endif
    fi
    cat > files.${mod} <<EOF
%{_libdir}/php/modules/${mod}.so
%config(noreplace) %{_sysconfdir}/php.d/${ini}
%if %{with zts}
%{_libdir}/php-zts/modules/${mod}.so
%config(noreplace) %{_sysconfdir}/php-zts.d/${ini}
%endif
EOF
done

# The dom, xsl and xml* modules are all packaged in php-xml
cat files.dom files.xsl files.xml{reader,writer} \
    files.simplexml >> files.xml

# mysqlnd
cat files.mysqli \
    files.pdo_mysql \
    >> files.mysqlnd

# Split out the PDO modules
cat files.pdo_pgsql >> files.pgsql
cat files.pdo_odbc >> files.odbc

# sysv* and posix in packaged in php-process
cat files.shmop files.sysv* files.posix > files.process

# Package sqlite3 and pdo_sqlite with pdo; isolating the sqlite dependency
# isn't useful at this time since rpm itself requires sqlite.
cat files.pdo_sqlite >> files.pdo
cat files.sqlite3 >> files.pdo

# Package curl, phar and fileinfo in -common.
cat files.curl files.phar files.fileinfo \
    files.exif files.gettext files.iconv files.calendar \
    files.ftp files.bz2 files.ctype \
    files.tokenizer > files.common

# The default Zend OPcache blacklist file
install -m 644 %{SOURCE51} $RPM_BUILD_ROOT%{_sysconfdir}/php.d/opcache-default.blacklist
%if %{with zts}
install -m 644 %{SOURCE51} $RPM_BUILD_ROOT%{_sysconfdir}/php-zts.d/opcache-default.blacklist
sed -e '/blacklist_filename/s/php.d/php-zts.d/' \
    -i $RPM_BUILD_ROOT%{_sysconfdir}/php-zts.d/10-opcache.ini
%endif

# Install the macros file:
sed -e "s/@PHP_APIVER@/%{apiver}-%{__isa_bits}/" \
    -e "s/@PHP_ZENDVER@/%{zendver}-%{__isa_bits}/" \
    -e "s/@PHP_PDOVER@/%{pdover}-%{__isa_bits}/" \
    -e "s/@PHP_VERSION@/%{version}/" \
%if ! %{with zts}
    -e "/zts/d" \
%endif
    < %{SOURCE3} > macros.php
install -m 644 -D macros.php \
           $RPM_BUILD_ROOT%{_rpmmacrodir}/macros.php

# Remove unpackaged files
rm -rf $RPM_BUILD_ROOT%{_libdir}/php/modules/*.a \
       $RPM_BUILD_ROOT%{_libdir}/php-zts/modules/*.a \
       $RPM_BUILD_ROOT%{_bindir}/{phptar} \
       $RPM_BUILD_ROOT%{_datadir}/pear \
       $RPM_BUILD_ROOT%{_bindir}/zts-phar* \
       $RPM_BUILD_ROOT%{_mandir}/man1/zts-phar* \
       $RPM_BUILD_ROOT%{_libdir}/libphp.a \
       $RPM_BUILD_ROOT%{_libdir}/libphp.la

# Remove irrelevant docs
rm -f README.{Zeus,QNX,CVS-RULES}


%post fpm
%systemd_post php-fpm.service

%preun fpm
%systemd_preun php-fpm.service

# Raised by new pool installation or new extension installation
%transfiletriggerin fpm -- %{_sysconfdir}/php-fpm.d %{_sysconfdir}/php.d
systemctl try-restart php-fpm.service >/dev/null 2>&1 || :


%files
%if %{with modphp}
%{_httpd_moddir}/libphp.so
%config(noreplace) %{_httpd_modconfdir}/20-php.conf
%attr(0770,root,apache) %dir %{_sharedstatedir}/php/session
%attr(0770,root,apache) %dir %{_sharedstatedir}/php/wsdlcache
%attr(0770,root,apache) %dir %{_sharedstatedir}/php/opcache
%config(noreplace) %{_httpd_confdir}/php.conf
%endif

%files common -f files.common
%doc EXTENSIONS NEWS UPGRADING* README.REDIST.BINS *md docs
%license LICENSE TSRM_LICENSE ZEND_LICENSE BOOST_LICENSE
%license libmagic_LICENSE
%license timelib_LICENSE
%doc php.ini-*
%config(noreplace) %{_sysconfdir}/php.ini
%dir %{_sysconfdir}/php.d
%dir %{_libdir}/php
%dir %{_libdir}/php/modules
%if %{with zts}
%dir %{_sysconfdir}/php-zts.d
%dir %{_libdir}/php-zts
%dir %{_libdir}/php-zts/modules
%endif
%dir %{_sharedstatedir}/php
%dir %{_sharedstatedir}/php/peclxml
%dir %{_datadir}/php
%dir %{_docdir}/pecl
%dir %{_datadir}/tests
%dir %{_datadir}/tests/pecl

%files cli
%{_bindir}/php
%if %{with zts}
%{_bindir}/zts-php
%{_mandir}/man1/zts-php.1*
%endif
%{_bindir}/php-cgi
%{_bindir}/phar.phar
%{_bindir}/phar
# provides phpize here (not in -devel) for pecl command
%{_bindir}/phpize
%{_mandir}/man1/php.1*
%{_mandir}/man1/php-cgi.1*
%{_mandir}/man1/phar.1*
%{_mandir}/man1/phar.phar.1*
%{_mandir}/man1/phpize.1*

%files dbg
%doc sapi/phpdbg/CREDITS
%{_bindir}/phpdbg
%{_mandir}/man1/phpdbg.1*
%if %{with zts}
%{_bindir}/zts-phpdbg
%{_mandir}/man1/zts-phpdbg.1*
%endif

%files fpm
%doc php-fpm.conf.default www.conf.default
%license fpm_LICENSE
%attr(0770,root,apache) %dir %{_sharedstatedir}/php/session
%attr(0770,root,apache) %dir %{_sharedstatedir}/php/wsdlcache
%attr(0770,root,apache) %dir %{_sharedstatedir}/php/opcache
%config(noreplace) %{_httpd_confdir}/php.conf
%config(noreplace) %{_sysconfdir}/php-fpm.conf
%config(noreplace) %{_sysconfdir}/php-fpm.d/www.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/php-fpm
%config(noreplace) %{_sysconfdir}/nginx/conf.d/php-fpm.conf
%config(noreplace) %{_sysconfdir}/nginx/default.d/php.conf
%{_unitdir}/php-fpm.service
%config(noreplace) %{_sysconfdir}/systemd/system/httpd.service.d/php-fpm.conf
%config(noreplace) %{_sysconfdir}/systemd/system/nginx.service.d/php-fpm.conf
%{_sbindir}/php-fpm
%dir %{_sysconfdir}/systemd/system/php-fpm.service.d
%dir %{_sysconfdir}/php-fpm.d
# log owned by apache for log
%attr(770,apache,root) %dir %{_localstatedir}/log/php-fpm
%dir %ghost /run/php-fpm
%{_mandir}/man8/php-fpm.8*
%dir %{_datadir}/fpm
%{_datadir}/fpm/status.html

%files devel
%{_bindir}/php-config
%{_includedir}/php
%{_libdir}/php/build
%if %{with zts}
%{_bindir}/zts-php-config
%{_bindir}/zts-phpize
%{_includedir}/php-zts
%{_libdir}/php-zts/build
%{_mandir}/man1/zts-php-config.1*
%{_mandir}/man1/zts-phpize.1*
%endif
%{_mandir}/man1/php-config.1*
%{_rpmmacrodir}/macros.php

%files embedded
%{_libdir}/libphp.so
%{_libdir}/libphp-%{embed_version}.so

%files pgsql -f files.pgsql
%files odbc -f files.odbc
%if %{with imap}
%files imap -f files.imap
%endif
%files ldap -f files.ldap
%files snmp -f files.snmp
%files xml -f files.xml
%files mbstring -f files.mbstring
%license libmbfl_LICENSE
%files gd -f files.gd
%files soap -f files.soap
%files bcmath -f files.bcmath
%license libbcmath_LICENSE
%files gmp -f files.gmp
%files dba -f files.dba
%files pdo -f files.pdo
%if %{with tidy}
%files tidy -f files.tidy
%endif
%if %{with freetds}
%files pdo-dblib -f files.pdo_dblib
%endif
%if %{with pspell}
%files pspell -f files.pspell
%endif
%files intl -f files.intl
%files process -f files.process
%if %{with firebird}
%files pdo-firebird -f files.pdo_firebird
%endif
%files enchant -f files.enchant
%files mysqlnd -f files.mysqlnd
%files opcache -f files.opcache
%config(noreplace) %{_sysconfdir}/php.d/opcache-default.blacklist
%if %{with zts}
%config(noreplace) %{_sysconfdir}/php-zts.d/opcache-default.blacklist
%endif
%if %{with sodium}
%files sodium -f files.sodium
%endif
%files ffi -f files.ffi
%dir %{_datadir}/php/preload


%changelog
* Tue Jul 15 2025 lzq11122 <lzq02303433@alibaba-inc.com> - 8.3.19-2
- add patch to fix CVE-2025-6491 and  CVE-2025-1735

* Wed Jun 11 2025 wenxin <wx02272781@alibaba-inc.com> - 8.3.19-1
- Update to 8.3.19 to fix CVE-2024-11235

* Fri Mar 21 2025 Zhao Hang <wb-zh951434@alibaba-inc.com> - 8.3.15-1
- Update to 8.3.15-1 from 8.2.27-1
- Migrated to SPDX license
- Remove patches which already exist in code
- enable command history in phpdbg, add internal UTC if tzdata is missing and backport Argon2 password hashing in OpenSSL ext
  [Patches cherry-pick from c10s. Original changelog:
  - rebase to 8.3.7
    backport Argon2 password hashing in OpenSSL ext
  - update to 8.3.0RC3 https://fedoraproject.org/wiki/Changes/php83
    add internal UTC if tzdata is missing
    bump to final API/ABI
    switch to nikic/php-parser version 5
    openssl: always warn about missing curve_name
  - rebase to 8.3.12
    enable command history in phpdbg
]

* Tue Jan 14 2025 yangxinyu <yangxinyu@nfschina.com> - 8.2.27-1
- Update to version 8.2.27
- fix cve-2024-8929 cve-2024-11233 cve-2024-11234

* Tue Dec 17 2024 yangxinyu <yangxinyu@nfschina.com> - 8.2.26-1
- Update to version 8.2.26

* Thu Nov 21 2024 yangxinyu <yangxinyu@nfschina.com> - 8.2.24-1
- Update to version 8.2.24

* Mon Jul 29 2024 Tingyin Duan <duanty@sugon.com> - 8.2.20-1
- Update to version 8.2.20

* Fri Sep 29 2023 Funda Wang <fundawang@yeah.net> - 8.2.11-1
- New version 8.2.11

* Wed Aug 30 2023 Funda Wang <fundawang@yeah.net> - 8.2.10-1
- New version 8.2.10
- Backport openssl ext enhancements from 8.3 branch for sm2

* Mon Aug 28 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 8.2.8-2
- Rebuild for sodium

* Sun Jul 9 2023 Funda Wang <fundawang@yeah.net> - 8.2.8-1
- New version 8.2.8

* Thu Jun 15 2023 Funda Wang <fundawang@yeah.net> - 8.2.7-1
- New version 8.2.7

* Fri May 12 2023 Funda Wang <fundawang@yeah.net> - 8.2.6-2
- Add missing version macro of zip extension

* Wed May 10 2023 Funda Wang <fundawang@yeah.net> - 8.2.6-1
- New version 8.2.6

* Tue Apr 18 2023 Zhongling He <zhonglingh@linux.alibaba.com> - 8.2.5-2
- refactor rpm spec

* Wed Apr 12 2023 Funda Wang <fundawang@yeah.net> - 8.2.5-1
- New version 8.2.5

* Wed Mar 15 2023 Funda Wang <fundawang@yeah.net> - 8.2.4-1
- New version 8.2.4
- Add zip extension for composer

* Sat Mar 04 2023 Funda Wang <fundawang@yeah.net> - 8.2.3-3
- Rebuild for new libpq

* Tue Feb 21 2023 Funda Wang <fundawang@yeah.net> - 8.2.3-2
- Add back forgotten ini files for opcache and ffi

* Tue Feb 14 2023 Funda Wang <fundawang@yeah.net> - 8.2.3-1
- New version 8.2.3

* Thu Feb 2 2023 Funda Wang <fundawang@yeah.net> - 8.2.2-1
- New version 8.2.2

* Fri Jan 6 2023 Funda Wang <fundawang@yeah.net> - 8.1.14-1
- New version 8.1.14

* Tue Dec 06 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 8.1.13-2
- rebuild with icu update

* Thu Nov 24 2022 Funda Wang <fundawang@yeah.net> - 8.1.13-1
- Update to 8.1.13

* Sat Oct 29 2022 Funda Wang <fundawang@yeah.net> - 8.1.12-1
- Update to 8.1.12

* Mon Sep 5 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 8.1.9-1
- Update to 8.1.9

* Mon May 30 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 8.1.6-2
- disable some components

* Tue May 17 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 8.1.6-1
- Init from upstream version 8.1.6
